#!/usr/bin/env python
# coding=utf8

# router
ROUTER = 'routes'
ROUTER_PATH = "path"
ROUTER_METHOD = "methods"
ROUTER_HANDLER = "handler"
ROUTER_OPTIONS = "options"

# pfrock
PFROCK_CONFIG_SERVER = 'servers'
PFROCK_CONFIG_ROUTER = 'routes'
PFROCK_CONFIG_PORT = 'port'
